import sys

from loguru import logger
# 移除 loguru 默认添加的所有处理器
logger.remove()

custom_format = "<green>{time:YYYY-MM-DD HH:mm:ss}</green> | <level>{level: <8}</level> | <cyan>{file}</cyan>:<cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>"
logger.level("PRINT", no=21, color="<black>")
# 添加控制台输出，使用控制台格式
# logger.add(sys.stderr, format=custom_format)
# 添加文件输出，使用文件格式
logger.add("logger_print.log", format=custom_format, rotation="1 week")

console_format = "<green>{file}:{function}:{line}</green> | <level>{message}</level>"

# 添加控制台输出，使用控制台格式
logger.add(sys.stderr, format=console_format, enqueue=False)

def print(*args, **kwargs):
    log_message = " ".join(str(arg) for arg in args)
    if 'sep' in kwargs:
        log_message = kwargs.get('sep', ' ').join(str(arg) for arg in args)
    logger.opt(depth=1).log("PRINT", log_message)

if __name__ == '__main__':
    print("你好", "哈哈哈")
    print("你好")


from setuptools import setup, find_packages

# 读取README.md文件的内容
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='logger_print',
    version='0.1',
    description='A simple package to redirect print statements to loguru logger.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    project_urls={
        'Source Code': 'https://github.com/glwhappen/logger_print',
    },
    author='glwhappen',
    author_email='1597721684@qq.com',
    packages=find_packages(),
    install_requires=[
        'loguru',
    ],
)